@@ -4,8 +4,8 @@
 
 ;; Author: Fabian Markl <fabian@markl.dev>
 ;; URL: https://github.com/F4ban/codespaces.el
-;; Package-Version: 20260225.2142
-;; Package-Revision: 11b8f9d690c0
+;; Package-Version: 20260226.2230
+;; Package-Revision: 3563a297e3bc
 ;; Package-Requires: ((emacs "28.1"))
 ;; Keywords: comm
 ;; Created: 2022-08-11
@@ -320,6 +320,14 @@ allowing for faster startup.  Validation happens lazily on first use."
                        (or codespaces-default-directory
                            (format "/workspaces/%s" (codespaces-space-repository-name selected)))))))
 
+(defun codespaces-delete ()
+  "Delete a codespace chosen by `completing-read`."
+  (interactive)
+  (let ((selected (codespaces--complete (codespaces--all-codespaces))))
+    (when (yes-or-no-p (format "Are you sure you want to delete the codespace '%s'?" (codespaces-space-name selected)))
+             (shell-command
+              (format "gh codespace delete -c %s --force" (codespaces-space-name selected))))))
+
 (provide 'codespaces)
 
 ;;; codespaces.el ends here
